# -*- coding: utf8 -*-
import unittest
import os, shutil
from Configuration import *

class GetCountryAndCityListTestCase(unittest.TestCase):
    def test_GetCountryInfoList(self):
        self.assert_(('KR', 'Korea') in getCountryInfoList())

    def test_GetCountryNameList(self):
        self.assert_('Korea' in getCountryNameList())

    def test_CountryNameToCode(self):
        self.assertEquals(countryNameToCode("Korea"), "KR")
        self.assertEquals(countryNameToCode("Japan"), "JP")
        self.assertEquals(countryNameToCode("MyCountry"), None)
        
    def test_GetCityList(self):
        self.assert_('Ansan' in getCityList("Korea")[0])
        self.assertEquals(getCityList("Korea")[1], 'Seoul')
        #self.assert_('Seoul' in getCityList("MyKingdom"))
        
class CongigurationTestCase(unittest.TestCase):
    def setUp(self):
        try: os.remove("config.cfg")
        except: pass
        
        try: shutil.rmtree("wallpapers")
        except: pass
        
        self.conf = Configuration()
        
    def test_SetCity(self):
        self.assertEquals(self.conf.city, "Seoul")
        self.conf.setCity("incheon")
        #self.assertEquals(self.conf.city, "incheon")
        #self.assertRaises(InvalidCityError, self.conf.setCity, "invalid city")

    def test_SetInterval(self):
        self.assertEquals(self.conf.interval, 300) # min

        self.assertRaises(InvalidIntervalError, self.conf.setInterval, 0)
        
        
    def test_SaveAndLoad(self):
        self.assertEquals(self.conf.city, "Seoul")
        self.conf.setCity("incheon")
        self.assertEquals(self.conf.save(), True)

        self.conf = Configuration() # self.conf.load()
        self.assertEquals(self.conf.city, "incheon")
        self.assertEquals(self.conf.interval, 300)

    def test_setImageOfWeather(self):
        self.conf.setImageOfWeather('A', 'B.BMP')

    def test_getWeatherList(self):
        self.assertEquals(self.conf.getWeatherList(), WEATHERLIST)
        
    def test_copyWallpaper(self):
        self.assert_(os.path.normpath('wallpapers/Clear') in self.conf.copyWallpaper("Clear", "testDatas/sky.jpg"))
        self.assert_(os.path.exists("wallpapers/Clear"))

    def test_setMode(self):
        self.conf = Configuration() # self.conf.load()
        self.assertEquals(self.conf.mode, "Weather")
        self.conf.setMode("Random")
        self.assertEquals(self.conf.mode, "Random")
        self.conf.save()

        newConf = Configuration() # self.conf.load()
        self.assertEquals(newConf.mode, "Random")

if __name__ == "__main__":
    unittest.main(argv=("", "-v"))
